#!/bin/bash

if [[ $# -ne 3 ]]; then
    echo "usage: ./build.sh [python] [clang] [hexagon-clang]"
    exit
fi

python=$1
clang=$2
hexagon_clang=$3

# Create output directories if they don't exist
[[ ! -d build ]] && mkdir build
[[ ! -d build/asm ]] && mkdir build/asm
[[ ! -d build/bin ]] && mkdir build/bin

# Create the semantics file
$clang src/gen_semantics.c -o build/gen_semantics
./build/gen_semantics build/semantics_generated.pyinc

# Emit asm for each instruction
num_loop_iterations=1000000
insn_per_iteration=100
$python src/emit_bench_asm.py build/semantics_generated.pyinc build/asm $num_loop_iterations $insn_per_iteration

# Compile asm
echo "Compiling:"
for asm in build/asm/*; do
    file=${asm##*/}
    filename=${file%%.*}
    echo $filename

    $hexagon_clang -g -nostdlib $asm -o build/bin/$filename -static -O2 -mv67t -mhvx
done
