#!/bin/bash

if [[ $(($# % 2)) -ne 0 ]]; then
    echo "Error: Needs a label and path for every version of QEMU you want to run!"
    echo "usage: ./run.sh [label1] [path1] [label2] [path2] ..."
    exit
fi

# Unpack args to script into separate arrays,
# we also use realpath to convert all paths
# to absolute ones
labels=()
qemus=()
for ((i=1; i<=$#; i=i+2)); do
    labels+=("${@:$i:1}")
    qemus+=($(realpath "${@:$i+1:1}"))
done

# Check that the paths are valid
for qemu in ${qemus[@]}; do
    if [[ ! -f $qemu ]]; then
        echo "Error: path ${qemu} not valid"
        exit
    fi
done

# Output header
echo "Instruction" "${labels[@]}"

# Loop over all executables in build/bin and run every version of
# QEMU passed in on them.
TIMEFORMAT="%3R"
for exe in build/bin/*; do
    file=${exe##*/}
    filename=${file%%.*}
    results=()
    for qemu in ${qemus[@]}; do
        out=$(time ($qemu $exe) 2>&1)
        # Break out if a test crashes
        if [[ $? -ne 0 ]]; then
            break
        fi
        results+=($out)
    done

    # Only output test results if all succeeded
    if [[ ${#qemus[@]} -eq ${#results[@]} ]]; then
        echo $filename "${results[@]}"
    fi
done
